@@ -9,7 +9,6 @@ from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 
 __all__ = ['Line', 'Move', 'MoveLine', 'OpenAccount']
-__metaclass__ = PoolMeta
 
 
 class Line(ModelSQL, ModelView):
@@ -67,8 +66,7 @@ class Line(ModelSQL, ModelView):
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
         super(Line, cls).__register__(module_name)
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         # Migration from 1.2 currency has been changed in function field
         table.not_null_action('currency', action='remove')
@@ -135,6 +133,7 @@ class Line(ModelSQL, ModelView):
 
 
 class Move:
+    __metaclass__ = PoolMeta
     __name__ = 'account.move'
 
     def cancel(self, default=None):
